cvs: SVNROOT / run-conversion.php

[email protected] ("Gwynne Raskind") Wed, 24 Jun 2009 13:25:47 -0000
Newsgroups svn.migration
Message-ID <cvsgwynne1245849947@cvsserver>
gwynne		Wed Jun 24 13:25:47 2009 UTC

  Modified files:              
    /SVNROOT	run-conversion.php 
  Log:
  pear/modules => pear/packages, by request of Christian Weiske
  
http://cvs.php.net/viewvc.cgi/SVNROOT/run-conversion.php?r1=1.63&r2=1.64&diff_format=u
Index: SVNROOT/run-conversion.php
diff -u SVNROOT/run-conversion.php:1.63 SVNROOT/run-conversion.php:1.64
--- SVNROOT/run-conversion.php:1.63	Sun Jun 21 17:19:19 2009
+++ SVNROOT/run-conversion.php	Wed Jun 24 13:25:47 2009
@@ -7,7 +7,7 @@
 
 // -----------------------------------------------------------------------------------------------------------------------------
 // Constants
-$version = substr('$Revision: 1.63 $', strlen('$Revision: '), -2);
+$version = substr('$Revision: 1.64 $', strlen('$Revision: '), -2);
 
 $passes = array(
     'processcvs',       // Process CVS modules
@@ -223,7 +223,7 @@
                 if (!is_dir($cvspath . $module) || 
                         count(scandir($cvspath . $module)) == 2 || $module == 'Attic' ||
                         ($moduleName == 'php/pecl' && in_array($module, array('libextractor', 'cudpp'))) ||
-                        ($moduleName == 'pear/modules' && in_array($module, array('HTML_QuickForm_ComboBox', 'Services_Compete', 'XML_HTMLSax3')))) {
+                        ($moduleName == 'pear/packages' && in_array($module, array('HTML_QuickForm_ComboBox', 'Services_Compete', 'XML_HTMLSax3')))) {
                     continue; // empty dir
                 }
                 // Add the submodule as a subdirectory of the meta-module. Notice the meta-module itself is never added.
@@ -326,13 +326,13 @@
     // Some renames:
     //      cvs/phpdoc      => cvs/doc-base ; Will be moved into phpdoc/ later
     //      cvs/phpdoc/en   => cvs/phpdoc-en ; Will be renamed to "en" and moved into phpdoc/ later
     //      cvs/pear        => cvs/modules ; This will be moved into a "pear" directory later
     //      cvs/TSRM        => cvs/php-src/TSRM ; Merge TSRM into php-src
     //      cvs/ZendEngine2 => cvs/php-src/ZendEngine2 ; Merge ZE2 into php-src
     //      cvs/pdo-specs   => cvs/pecl/pdo/specs ; This didn't belong as a separate module to begin with and will be merged into PECL's PDO
     mv("{$cvsPath}/phpdoc", "{$cvsPath}/doc-base");
     mv("{$cvsPath}/doc-base/en", "{$cvsPath}/phpdoc-en");
-    mv("{$cvsPath}/pear", "{$cvsPath}/modules");
+    mv("{$cvsPath}/pear", "{$cvsPath}/packages");
     mv("{$cvsPath}/TSRM", "{$cvsPath}/php-src/TSRM");
     mv("{$cvsPath}/ZendEngine2", "{$cvsPath}/php-src/ZendEngine2");
     mv("{$cvsPath}/pdo-specs", "{$cvsPath}/pecl/pdo/specs");
@@ -376,9 +376,9 @@
             $converter->addCVSModule("php/{$cvs_module}", $cvs_module == 'pecl');
         // Modules belonging to PEAR (especially the "modules" directory which contains all PEAR modules) go into cvs/pear/<module>
         //  PEAR/modules is a meta-module. (see CVS2SVNConverter::addCVSModule)
-        } else if (in_array($cvs_module, array('modules', 'pearbot', 'pear-core', 'peardoc', 'pearweb'))) {
+        } else if (in_array($cvs_module, array('packages', 'pearbot', 'pear-core', 'peardoc', 'pearweb'))) {
             mv("{$cvsPath}/{$cvs_module}", "{$cvsPath}/pear/{$cvs_module}");
-            $converter->addCVSModule("pear/{$cvs_module}", $cvs_module == 'modules');
+            $converter->addCVSModule("pear/{$cvs_module}", $cvs_module == 'packages');
         // Modules belonging to websites, including the presentation, bugtracker, and pecl4win modules, go into cvs/web/<module>
         //  All modules that end in web are matched, and added with the "-?web" suffix stripped.
         } else if (substr($cvs_module, -3) == "web" || in_array($cvs_module, array('pres2', 'presentations', 'bugtracker', 'pecl4win'))) {
@@ -408,7 +408,7 @@
     }
     
     // Strip any .svn dirs that might've been accidentally committed to CVS from other checkouts to avoid confusing the heck out of cvs2svn
-    run_command('find ' . escapeshellarg("{$cvsPath}/pear/modules") . " -name '.svn' -type d -print0 | xargs -0 rm -Rf");
+    run_command('find ' . escapeshellarg("{$cvsPath}/pear/packages") . " -name '.svn' -type d -print0 | xargs -0 rm -Rf");
 }
     
 // -----------------------------------------------------------------------------------------------------------------------------
@@ -326,13 +326,13 @@
     //      cvs/phpdoc      => cvs/doc-base ; Will be moved into phpdoc/ later
     //      cvs/phpdoc/en   => cvs/phpdoc-en ; Will be renamed to "en" and moved into phpdoc/ later
-    //      cvs/pear        => cvs/modules ; This will be moved into a "pear" directory later
+    //      cvs/pear        => cvs/packages ; This will be moved into a "pear" directory later
     //      cvs/TSRM        => cvs/php-src/TSRM ; Merge TSRM into php-src
     //      cvs/ZendEngine2 => cvs/php-src/ZendEngine2 ; Merge ZE2 into php-src